# remirepo spec file for php-pecl-ip2proxy
#
# Copyright (c) 2020-2021 Remi Collet
# License: CC-BY-SA
# http://creativecommons.org/licenses/by-sa/4.0/
#
# Please, preserve the changelog entries
#
%if 0%{?scl:1}
%global sub_prefix %{scl_prefix}
%scl_package       php-pecl-ip2proxy
%endif

%bcond_without     tests

%global pecl_name  ip2proxy
%global with_zts   0%{!?_without_zts:%{?__ztsphp:1}}
%if "%{php_version}" < "5.6"
%global ini_name  %{pecl_name}.ini
%else
%global ini_name   40-%{pecl_name}.ini
%endif

%global upstream_version 3.0.1
#global upstream_prever  RC1

# see https://github.com/ip2location/ip2proxy-c/commits/master
%global gh_owner    ip2location
%global gh_project  ip2proxy-c
%global gh_commit   00154dc0b5d260d6c6ba86f9d997b9395c56fd22
%global gh_version  4.0.1
%global gh_short    %(c=%{gh_commit}; echo ${c:0:7})

Summary:        Get proxy information of an IP address
Name:           %{?sub_prefix}php-pecl-%{pecl_name}
# library is MIT, extension is PHP
License:        MIT and PHP
Version:        %{upstream_version}%{?upstream_prever:~%{upstream_prever}}
Release:        2%{?dist}%{!?nophptag:%(%{__php} -r 'echo ".".PHP_MAJOR_VERSION.".".PHP_MINOR_VERSION;')}
URL:            https://pecl.php.net/package/igbinary
Source0:        https://pecl.php.net/get/%{pecl_name}-%{upstream_version}%{?upstream_prever}.tgz

# library with no API nor ABI management
Source1:        https://github.com/%{gh_owner}/%{gh_project}/archive/%{gh_commit}/%{gh_project}-%{gh_version}-%{gh_short}.tar.gz
Patch0:         %{pecl_name}-bundledlib.patch
Provides:       bundled(%{gh_project}) = %{gh_version}

BuildRequires:  make
BuildRequires:  %{?dtsprefix}gcc
BuildRequires:  %{?scl_prefix}php-pear
BuildRequires:  %{?scl_prefix}php-devel

Requires:       %{?scl_prefix}php(zend-abi) = %{php_zend_api}
Requires:       %{?scl_prefix}php(api) = %{php_core_api}
%{?_sclreq:Requires: %{?scl_prefix}runtime%{?_sclreq}%{?_isa}}

Provides:       %{?scl_prefix}php-%{pecl_name}                = %{version}
Provides:       %{?scl_prefix}php-%{pecl_name}%{?_isa}        = %{version}
Provides:       %{?scl_prefix}php-pecl(%{pecl_name})          = %{version}
Provides:       %{?scl_prefix}php-pecl(%{pecl_name})%{?_isa}  = %{version}
%if "%{?scl_prefix}" != "%{?sub_prefix}"
Provides:       %{?scl_prefix}php-pecl-%{pecl_name}           = %{version}-%{release}
Provides:       %{?scl_prefix}php-pecl-%{pecl_name}%{?_isa}   = %{version}-%{release}
%endif

%if "%{?packager}" == "Remi Collet" && 0%{!?scl:1} && 0%{?rhel}
# Other third party repo stuff
%if "%{php_version}" > "7.3"
Obsoletes:      php73-pecl-%{pecl_name}  <= %{version}
%endif
%if "%{php_version}" > "7.4"
Obsoletes:      php74-pecl-%{pecl_name}  <= %{version}
%endif
%if "%{php_version}" > "8.0"
Obsoletes:      php80-pecl-%{pecl_name}  <= %{version}
%endif
%if "%{php_version}" > "8.1"
Obsoletes:      php80-pecl-%{pecl_name}  <= %{version}
%endif
%endif


%description
This PECL extension allows you to detect proxy servers with country,
region, city, ISP, domain, usage type, ASN, security threat and proxy
type information using IP2Proxy binary database.

Package built for PHP %(%{__php} -r 'echo PHP_MAJOR_VERSION.".".PHP_MINOR_VERSION;')%{?scl: as Software Collection (%{scl} by %{?scl_vendor}%{!?scl_vendor:rh})}.


%prep
%setup -q -c -a 1
mv %{gh_project}-%{gh_commit}/libIP2Proxy libIP2Proxy
mv %{gh_project}-%{gh_commit}/LICENSE.TXT LICENSE-%{gh_project}
mv %{pecl_name}-%{upstream_version}%{?upstream_prever} NTS

# Don't install tests
sed -e 's/role="test"/role="src"/' \
    %{?_licensedir:-e '/LICENSE/s/role="doc"/role="src"/' } \
    -e '/README.TXT/s/role="doc"/role="src"/' \
    -i package.xml

cd NTS
%patch0 -p1 -b .rpm

# Check version
extver=$(sed -n '/#define PHP_IP2PROXY_VERSION/{s/.* "//;s/".*$//;p}' php_ip2proxy.h)
if test "x${extver}" != "x%{upstream_version}%{?upstream_prever}"; then
   : Error: Upstream version is ${extver}, expecting %{upstream_version}%{?upstream_prever}.
   exit 1
fi
cd ..

%if %{with_zts}
cp -r NTS ZTS
%endif

cat <<EOF | tee %{ini_name}
; Enable %{pecl_name} extension module
extension=%{pecl_name}.so
EOF


%build
%{?dtsenable}

cd NTS
%{_bindir}/phpize
%configure \
  --with-ip2proxy=../libIP2Proxy \
  --with-php-config=%{_bindir}/php-config 
make %{?_smp_mflags}

%if %{with_zts}
cd ../ZTS
%{_bindir}/zts-phpize
%configure \
  --with-ip2proxy=../libIP2Proxy \
  --with-php-config=%{_bindir}/zts-php-config
make %{?_smp_mflags}
%endif


%install
%{?dtsenable}

make install -C NTS INSTALL_ROOT=%{buildroot}

install -D -m 644 package.xml %{buildroot}%{pecl_xmldir}/%{name}.xml

install -D -m 644 %{ini_name} %{buildroot}%{php_inidir}/%{ini_name}

# Install the ZTS stuff
%if %{with_zts}
make install -C ZTS INSTALL_ROOT=%{buildroot}
install -D -m 644 %{ini_name} %{buildroot}%{php_ztsinidir}/%{ini_name}
%endif

# Documentation
for i in $(grep 'role="doc"' package.xml | sed -e 's/^.*name="//;s/".*$//')
do install -Dpm 644 NTS/$i %{buildroot}%{pecl_docdir}/%{pecl_name}/$i
done


%check
: simple NTS module load test
%{_bindir}/php --no-php-ini \
    --define extension=%{buildroot}%{php_extdir}/%{pecl_name}.so \
    --modules | grep %{pecl_name}

%if %{with tests}
: upstream test suite
cd NTS
TEST_PHP_EXECUTABLE=%{_bindir}/php \
TEST_PHP_ARGS="-n -d extension=%{buildroot}%{php_extdir}/%{pecl_name}.so" \
REPORT_EXIT_STATUS=1 \
%{_bindir}/php -n run-tests.php -q --show-diff
%endif

%if %{with_zts}
: simple ZTS module load test
%{__ztsphp} --no-php-ini \
    --define extension=%{buildroot}%{php_ztsextdir}/%{pecl_name}.so \
    --modules | grep %{pecl_name}

%if %{with tests}
: upstream test suite
cd ../ZTS
TEST_PHP_EXECUTABLE=%{__ztsphp} \
TEST_PHP_ARGS="-n -d extension=%{buildroot}%{php_ztsextdir}/%{pecl_name}.so" \
REPORT_EXIT_STATUS=1 \
%{__ztsphp} -n run-tests.php -q --show-diff
%endif
%endif


%if 0%{?fedora} < 24 && 0%{?rhel} < 8
# when pear installed alone, after us
%triggerin -- %{?scl_prefix}php-pear
if [ -x %{__pecl} ] ; then
    %{pecl_install} %{pecl_xmldir}/%{name}.xml >/dev/null || :
fi

# posttrans as pear can be installed after us
%posttrans
if [ -x %{__pecl} ] ; then
    %{pecl_install} %{pecl_xmldir}/%{name}.xml >/dev/null || :
fi

%postun
if [ $1 -eq 0 -a -x %{__pecl} ] ; then
    %{pecl_uninstall} %{pecl_name} >/dev/null || :
fi
%endif


%files
%{!?_licensedir:%global license %%doc}
%license LICENSE-%{gh_project}
%{?_licensedir:%license NTS/LICENSE}
%doc %{pecl_docdir}/%{pecl_name}
%config(noreplace) %{php_inidir}/%{ini_name}

%{php_extdir}/%{pecl_name}.so
%{pecl_xmldir}/%{name}.xml

%if %{with_zts}
%config(noreplace) %{php_ztsinidir}/%{ini_name}
%{php_ztsextdir}/%{pecl_name}.so
%endif


%changelog
* Tue Nov 23 2021 Remi Collet <remi@remirepo.net> - 3.0.1-2
- update bundled libip2proxy to 4.0.1

* Fri Oct 23 2020 Remi Collet <remi@remirepo.net> - 3.0.1-1
- update to 3.0.1

* Thu Oct 22 2020 Remi Collet <remi@remirepo.net> - 3.0.0-2
- add bundled library license file

* Thu Oct 22 2020 Remi Collet <remi@remirepo.net> - 3.0.0-1
- initital RPM
- open https://github.com/ip2location/ip2proxy-pecl/issues/1 package.xml
- open https://github.com/ip2location/ip2proxy-pecl/issues/2 test suite
- open https://github.com/ip2location/ip2proxy-pecl/issues/3 empty file
